@@ -27,8 +27,8 @@ class User(deeplabel.basemodel.DeeplabelBase):
 
     @classmethod
     def from_login(cls, email: str, password: str, client: "deeplabel.client.BaseClient")->"User": #type: ignore
-        res = client.post(
-            "/users/login",
+        res = client.session.post(
+            client.label_url.rstrip('/')+"/users/login",
             json={"email": email, "password": password},
             headers={"Content-Type": "application/json"},
         )
