@@ -1,6 +1,6 @@
 from typing import Any, Dict, List, Optional
 from deeplabel.basemodel import DeeplabelBase
-from deeplabel.label.labels import DetectionLabel
+import deeplabel.label.labels as labels
 import deeplabel.client
 from logging import getLogger
 logger = getLogger(__name__)
@@ -10,7 +10,7 @@ logger = getLogger(__name__)
 class LabelMap(DeeplabelBase):
     """Detection Label"""
     label_id:str
-    label:DetectionLabel
+    label:labels.DetectionLabel
     name_lower:Optional[str]
     project_id:str
 
